@@ -76,6 +76,18 @@ POSSIBILITY OF SUCH DAMAGE.
 #include "libtorrent/debug.hpp"
 #include "libtorrent/aux_/file_progress.hpp"
 
+#ifdef TORRENT_USE_OPENSSL
+// there is no forward declaration header for asio
+namespace boost {
+namespace asio {
+namespace ssl {
+	struct context;
+	class verify_context;
+}
+}
+}
+#endif
+
 #if TORRENT_COMPLETE_TYPES_REQUIRED
 #include "libtorrent/peer_connection.hpp"
 #endif
@@ -556,15 +568,8 @@ namespace libtorrent
 		void connect_to_url_seed(std::list<web_seed_t>::iterator url);
 		bool connect_to_peer(torrent_peer* peerinfo, bool ignore_limit = false);
 
-		int priority() const { return m_priority; }
-		void set_priority(int prio)
-		{
-			TORRENT_ASSERT(prio <= 255 && prio >= 0);
-			if (prio > 255) prio = 255;
-			else if (prio < 0) prio = 0;
-			m_priority = prio;
-			state_updated();
-		}
+		int priority() const;
+		void set_priority(int const prio);
 
 #ifndef TORRENT_NO_DEPRECATE
 		// deprecated in 1.1
@@ -732,8 +737,7 @@ namespace libtorrent
 		void force_tracker_request(time_point, int tracker_idx);
 		void scrape_tracker(int idx, bool user_triggered);
 		void announce_with_tracker(boost::uint8_t e
-			= tracker_request::none
-			, address const& bind_interface = address_v4::any());
+			= tracker_request::none);
 		int seconds_since_last_scrape() const
 		{
 			return m_last_scrape == (std::numeric_limits<boost::int16_t>::min)()
@@ -1030,7 +1034,7 @@ namespace libtorrent
 
 		// renames the file with the given index to the new name
 		// the name may include a directory path
-		// returns false on failure
+		// posts alert to indicate success or failure
 		void rename_file(int index, std::string const& name);
 
 		// unless this returns true, new connections must wait
@@ -1168,6 +1172,10 @@ namespace libtorrent
 		void on_file_renamed(disk_io_job const* j);
 		void on_cache_flushed(disk_io_job const* j);
 
+		// this is used when a torrent is being removed.It synchronizes with the
+		// disk thread
+		void on_torrent_aborted();
+
 		// upload and download rate limits for the torrent
 		void set_limit_impl(int limit, int channel, bool state_update = true);
 		int limit_impl(int channel) const;
@@ -1602,10 +1610,7 @@ namespace libtorrent
 		// the number of bytes of padding files
 		boost::uint32_t m_padding:24;
 
-		// this is the priority of the torrent. The higher
-		// the value is, the more bandwidth is assigned to
-		// the torrent's peers
-		boost::uint32_t m_priority:8;
+		// TODO: gap of 8 bits available here
 
 // ----
 
